@@ -131,7 +131,7 @@ def commit(home, msg=None):
         changed = True
         delete = open(j(redd_home, 'delete.txt'), 'w')
         for filename in delta['added']:
-            delete.write("%s\n" % filename)
+            delete.write("%s\n" % urllib.quote(filename))
         delete.close()
 
     if len(delta['modified']) > 0:
@@ -140,7 +140,7 @@ def commit(home, msg=None):
             os.mkdir(j(redd_home, 'add'))
         delete = open(j(redd_home, 'delete.txt'), 'a')
         for filename in delta['modified']:
-            delete.write("%s\n" % filename)
+            delete.write("%s\n" % urllib.quote(filename))
             os.renames(j(home, v1, 'full', filename), j(redd_home, 'add', filename))
         delete.close()
 
@@ -179,7 +179,7 @@ def export(home, version):
         if os.path.isfile(j(home, dv, 'delta', 'delete.txt')):
             deletes = open(j(home, dv, 'delta', 'delete.txt')).read().split()
             for delete in deletes:
-                os.remove(j(home, export, 'full', delete))
+                os.remove(j(home, export, 'full', urllib.unquote(delete)))
 
         # add added files
         if os.path.isdir(j(home, dv, 'delta', 'add')): 
@@ -192,6 +192,7 @@ def status(home):
     v1 = _current_version(home)
     _print("current version: %s" % v1)
     v2 = _latest_version(home)
+    _print("working version: %s" % v2)
     if v1 == v2:
         _print("no changes")
         delta = None
@@ -265,7 +266,6 @@ def _new_version(home):
     os.mkdir(j(home, v, 'full', 'metadata'))
     open(j(home, v, 'manifest.txt'), 'w')
     open(j(home, v, 'full', 'relationships.ttl'), 'w')
-    open(j(home, v, 'full', 'splash.txt'), 'w')
     return v
 
 def _next_version(home):
